#!/usr/bin/ruby

storage = Storage.new()
storage.load

command :start do |c|
    c.syntax = 'trakr start project'
    c.summary = 'start the timer'
    c.description = 'Starts the timer for a given project'
    c.example 'An example', 'trakr start project'
    c.action do |args|
        storage.database[args.first].start_timer
        storage.write!
    end
end


command :stop do |c|
    c.syntax = 'trakr stop project'
    c.summary = 'stop the timer'
    c.description = 'Stops the timer for a given project'
    c.example 'description','trakr stop project'
    c.action do |args|
        storage.database[args.first].stop_timer
        storage.write!
    end
end


command :new do |c|
    c.syntax = 'trakr new project, [options]'
    c.summary = 'add a new project'
    c.description = 'Add a new project to a database.'
    c.example 'Create a project', 'trakr new project'
    c.option '--estimate', 'State the estimated time for completion'
    c.action do |args, options|
        next if args.first == ""
        puts "Name cannot be empty"
        storage.database.merge!(args.first => Project.new(args.first, options.estimate))
        storage.write!
    end
end

command :remove do |c|
    c.syntax = 'trakr remove project'
    c.summary = 'remove a project'
    c.description = 'Remove a project from the database'
    c.example 'Remove project', 'trakr remove project'
    c.action do |args|
        storage.database.delete(args.first)
        storage.write!
    end
end

command :list do |c|
    c.syntax = 'trakr list'
    c.summary = 'show the list'
    c.description = 'Display a table of projects'
    c.example 'Show table', 'trakr list'
    c.action do
        rows = []
        storage.database.each_value do |v|
            rows << v.to_a
        end
        puts Terminal::Table.new :headings => Project.headings, :rows => rows
    end
end
alias_command :'ls', :'list'
